[PATCHv3 3/5] of: base: Add of_parse_phandle_from

Teresa Gámez t.gamez at phytec.de
Tue Sep 30 04:15:28 PDT 2014


Added of_parse_phandle_from() to be able to use external root nodes.

Signed-off-by: Teresa Gámez <t.gamez at phytec.de>
---
 drivers/of/base.c | 28 ++++++++++++++++++++++++----
 include/of.h      | 11 +++++++++++
 2 files changed, 35 insertions(+), 4 deletions(-)

diff --git a/include/of.h b/include/of.h
index 4281cce..decf151 100644
--- a/include/of.h
+++ b/include/of.h
@@ -205,6 +205,10 @@ extern int of_property_write_u64_array(struct device_node *np,
 extern struct device_node *of_parse_phandle(const struct device_node *np,
 					    const char *phandle_name,
 					    int index);
+extern struct device_node *of_parse_phandle_from(const struct device_node *np,
+					    struct device_node *root,
+					    const char *phandle_name,
+					    int index);
 extern int of_parse_phandle_with_args(const struct device_node *np,
 	const char *list_name, const char *cells_name, int index,
 	struct of_phandle_args *out_args);
@@ -439,6 +443,13 @@ static inline struct device_node *of_parse_phandle(const struct device_node *np,
 	return NULL;
 }
 
+static inline struct device_node *of_parse_phandle_from(const struct device_node *np,
+					    struct device_node *root,
+					    const char *phandle_name, int index)
+{
+	return NULL;
+}
+
 static inline int of_parse_phandle_with_args(const struct device_node *np,
 		const char *list_name, const char *cells_name, int index,
 		struct of_phandle_args *out_args)
diff --git a/drivers/of/base.c b/drivers/of/base.c
index 061fc79..f363cc1 100644
--- a/drivers/of/base.c
+++ b/drivers/of/base.c
@@ -1130,16 +1130,19 @@ int of_property_write_u64_array(struct device_node *np,
 }
 
 /**
  * of_parse_phandle - Resolve a phandle property to a device_node pointer
  * @np: Pointer to device node holding phandle property
+ * @root: root node of the tree to search in. If NULL use the internal tree.
  * @phandle_name: Name of property holding a phandle value
  * @index: For properties holding a table of phandles, this is the index into
  *         the table
  *
  * Returns the device_node pointer found or NULL.
  */
-struct device_node *of_parse_phandle(const struct device_node *np,
-				     const char *phandle_name, int index)
+struct device_node *of_parse_phandle_from(const struct device_node *np,
+					struct device_node *root,
+					const char *phandle_name, int index)
 {
 	const __be32 *phandle;
 	int size;
@@ -1148,7 +1151,24 @@ struct device_node *of_parse_phandle(const struct device_node *np,
 	if ((!phandle) || (size < sizeof(*phandle) * (index + 1)))
 		return NULL;
 
-	return of_find_node_by_phandle(be32_to_cpup(phandle + index));
+	return of_find_node_by_phandle_from(be32_to_cpup(phandle + index),
+					root);
+}
+EXPORT_SYMBOL(of_parse_phandle_from);
+
+/**
+ * of_parse_phandle - Resolve a phandle property to a device_node pointer
+ * @np: Pointer to device node holding phandle property
+ * @phandle_name: Name of property holding a phandle value
+ * @index: For properties holding a table of phandles, this is the index into
+ *         the table
+ *
+ * Returns the device_node pointer found or NULL.
+ */
+struct device_node *of_parse_phandle(const struct device_node *np,
+				     const char *phandle_name, int index)
+{
+	return of_parse_phandle_from(np, root_node, phandle_name, index);
 }
 EXPORT_SYMBOL(of_parse_phandle);
 
@@ -1130,16 +1130,19 @@ int of_property_write_u64_array(struct device_node *np,
 
 /**
- * of_parse_phandle - Resolve a phandle property to a device_node pointer
+ * of_parse_phandle_from - Resolve a phandle property to a device_node pointer from
+ * a given root node
  * @np: Pointer to device node holding phandle property
-- 
1.9.1




More information about the barebox mailing list